/// <reference types="koa" />
import { Middleware } from 'koa';
import { IConfiguration, Configuration } from './Configuration';
import { IContainer, LoadOptions, IContainerBuilder, Type, Token } from 'tsioc';
import { Application, IMiddleware } from './core';
/**
 * Bootstrap
 *
 * @export
 * @class Bootstrap
 */
export declare class Bootstrap {
    private rootdir;
    protected appType: Type<Application>;
    private container;
    private middlewares;
    private configDefer;
    private builder;
    /**
     * Creates an instance of WebApplication.
     * @param {string} rootdir
     * @param {Type<any>} [appType]
     * @memberof WebApplication
     */
    constructor(rootdir: string, appType?: Type<Application>);
    /**
     * create new application.
     *
     * @static
     * @param {string} rootdir
     * @param {Type<Application>} [appType]
     * @returns
     * @memberof WebApplication
     */
    static create(rootdir: string, appType?: Type<Application>): Bootstrap;
    /**
     * user custom IContainer.
     *
     * @param {(IContainer | Promise<IContainer>)} [container]
     * @returns
     *
     * @memberOf WebHostBuilder
     */
    useContainer(container: IContainer | Promise<IContainer>): this;
    getContainer(): Promise<IContainer>;
    protected createContainer(option?: LoadOptions): Promise<IContainer>;
    useContainerBuilder(builder: IContainerBuilder): this;
    getContainerBuilder(): IContainerBuilder;
    /**
     * use custom configuration.
     *
     * @param {(string | IConfiguration)} [config]
     * @returns {Bootstrap}
     *
     * @memberOf WebHostBuilder
     */
    useConfiguration(config?: string | IConfiguration): Bootstrap;
    getConfiguration(): Promise<Configuration>;
    /**
     * use middleware `fn` or  `MiddlewareFactory`.
     * @param {MvcMiddleware} middleware
     * @returns {Bootstrap}
     * @memberOf WebHostBuilder
     */
    use(middleware: IMiddleware | Middleware | Token<any>): Bootstrap;
    /**
     * run service.
     *
     * @param {Function} [listener]
     * @returns
     * @memberof Bootstrap
     */
    run(listener?: Function): Promise<Application>;
    /**
     * build application.
     * @returns {Bootstrap}
     * @memberOf WebHostBuilder
     */
    protected build(): Promise<Application>;
    protected initIContainer(config: Configuration, container: IContainer): Promise<IContainer>;
    protected registerDefaultMiddlewars(container: IContainer): void;
    protected registerDefaults(container: IContainer): void;
    protected setupRoutes(config: IConfiguration, container: IContainer): void;
    protected setupMiddwares(app: Application, container: IContainer, middlewares: Token<any>[], excludes: Token<any>[]): Application;
}
