"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
Object.defineProperty(exports, "__esModule", { value: true });
var tsioc_1 = require("tsioc");
var util_1 = require("util");
var decorators_1 = require("../decorators");
var Configuration_1 = require("../../Configuration");
var ModelParser = /** @class */ (function () {
    function ModelParser(container, config) {
        this.container = container;
        this.config = config;
    }
    ModelParser.prototype.isModel = function (type) {
        if (this.config.modelOptions) {
            return Reflect.hasOwnMetadata(this.config.modelOptions.classMetaname, type);
        }
        else {
            return Reflect.hasOwnMetadata(decorators_1.Model.toString(), type);
        }
    };
    ModelParser.prototype.getPropertyMeta = function (type) {
        var meta;
        if (this.config.modelOptions) {
            meta = tsioc_1.getPropertyMetadata(this.config.modelOptions.fieldMetaname, type);
        }
        else {
            meta = tsioc_1.getPropertyMetadata(decorators_1.Field, type);
        }
        return meta;
    };
    ModelParser.prototype.parseModel = function (type, objMap) {
        var meta = this.getPropertyMeta(type);
        var result = this.container.get(type);
        for (var n in meta) {
            var propmetas = meta[n];
            if (propmetas.length) {
                if (!util_1.isUndefined(objMap[n])) {
                    var propmeta = propmetas.find(function (p) { return !!p.type; });
                    var reqval = objMap[n];
                    var parmVal = void 0;
                    if (this.isBaseType(propmeta.type)) {
                        parmVal = this.parseBaseType(propmeta.type, reqval);
                    }
                    else if (tsioc_1.isClass(propmeta.type) && this.isModel(propmeta.type)) {
                        parmVal = this.parseModel(propmeta.type, reqval);
                    }
                    result[n] = parmVal;
                }
            }
        }
        return result;
    };
    ModelParser.prototype.parseBaseType = function (type, paramVal) {
        var val;
        if (type === String) {
            val = String(paramVal);
        }
        else if (type === Boolean) {
            val = new Boolean(paramVal);
        }
        else if (type === Number) {
            val = parseFloat(paramVal);
        }
        else if (type === Date) {
            val = new Date(paramVal);
        }
        else {
            val = paramVal;
        }
        return val;
    };
    ModelParser.prototype.isBaseType = function (p) {
        if (!tsioc_1.isToken(p)) {
            return true;
        }
        if (p === Boolean || p === String || p === Number || p === Date) {
            return true;
        }
        return false;
    };
    ModelParser = __decorate([
        tsioc_1.Singleton,
        __param(0, tsioc_1.Inject(tsioc_1.symbols.IContainer)),
        __metadata("design:paramtypes", [Object, Configuration_1.Configuration])
    ], ModelParser);
    return ModelParser;
}());
exports.ModelParser = ModelParser;

//# sourceMappingURL=../../sourcemaps/core/router/ModelParser.js.map
